@@ -1,3 +1,8 @@
+//! Suffix schemes determine the suffix of rotated files
+//!
+//! This behaviour is fully extensible through the [SuffixScheme] trait, and two behaviours are
+//! provided: [AppendCount] and [AppendTimestamp]
+//!
 use crate::SuffixInfo;
 #[cfg(feature = "chrono04")]
 use chrono::{offset::Local, Duration, NaiveDateTime};
@@ -59,7 +64,19 @@ pub trait SuffixScheme {
             .file_name()
             .expect("basepath.file_name()")
             .to_string_lossy();
+
+        // We need the parent directory of the given basepath, but this should also work when the path
+        // only has one segment. Thus we prepend the current working dir if the path is relative:
+        let basepath = if basepath.is_relative() {
+            let mut path = std::env::current_dir().unwrap();
+            path.push(basepath);
+            path
+        } else {
+            basepath.to_path_buf()
+        };
+
         let parent = basepath.parent().unwrap();
+
         let filenames = std::fs::read_dir(parent)
             .unwrap()
             .filter_map(|entry| entry.ok())
@@ -85,15 +102,16 @@ fn prepare_filename(path: &str) -> (&str, bool) {
         .unwrap_or((path, false))
 }
 
-/// Rotated log files get a number as suffix. The greater the number, the older. The oldest files
-/// are deleted.
-pub struct CountSuffix {
+/// Append a number when rotating the file.
+/// The greater the number, the older. The oldest files are deleted.
+pub struct AppendCount {
     max_files: usize,
 }
 
-impl CountSuffix {
-    /// New CountSuffix, deleting files when the total number of files exceeds `max_files`.
-    /// For example, if max_files is 3, then the files `log`, `log.1`, `log.2`, `log.3` may exist
+impl AppendCount {
+    /// New suffix scheme, deleting files when the number of rotated files (i.e. excluding the main
+    /// file) exceeds `max_files`.
+    /// For example, if `max_files` is 3, then the files `log`, `log.1`, `log.2`, `log.3` may exist
     /// but not `log.4`. In other words, `max_files` determines the largest possible suffix number.
     pub fn new(max_files: usize) -> Self {
         Self { max_files }
@@ -101,7 +119,7 @@ impl CountSuffix {
 }
 
 impl Representation for usize {}
-impl SuffixScheme for CountSuffix {
+impl SuffixScheme for AppendCount {
     type Repr = usize;
     fn rotate_file(
         &mut self,
@@ -122,11 +140,14 @@ impl SuffixScheme for CountSuffix {
     }
 }
 
+/// Append current timestamp as suffix when rotating files.
+/// If the timestamp already exists, an additional number is appended.
+///
 /// Current limitations:
-///  - Neither `format` or the base filename can include the character `"."`.
+///  - Neither `format` nor the base filename can include the character `"."`.
 ///  - The `format` should ensure that the lexical and chronological orderings are the same
 #[cfg(feature = "chrono04")]
-pub struct TimestampSuffixScheme {
+pub struct AppendTimestamp {
     /// The format of the timestamp suffix
     pub format: &'static str,
     /// The file limit, e.g. when to delete an old file - by age (given by suffix) or by number of files
@@ -134,7 +155,7 @@ pub struct TimestampSuffixScheme {
 }
 
 #[cfg(feature = "chrono04")]
-impl TimestampSuffixScheme {
+impl AppendTimestamp {
     /// With format `"%Y%m%dT%H%M%S"`
     pub fn default(file_limit: FileLimit) -> Self {
         Self {
@@ -142,13 +163,13 @@ impl TimestampSuffixScheme {
             file_limit,
         }
     }
-    /// Create new TimestampSuffixScheme suffix scheme
+    /// Create new AppendTimestamp suffix scheme
     pub fn with_format(format: &'static str, file_limit: FileLimit) -> Self {
         Self { format, file_limit }
     }
 }
 
-/// Structured representation of the suffixes of TimestampSuffixScheme.
+/// Structured representation of the suffixes of AppendTimestamp.
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct TimestampSuffix {
     /// The timestamp
@@ -182,7 +203,7 @@ impl std::fmt::Display for TimestampSuffix {
 }
 
 #[cfg(feature = "chrono04")]
-impl SuffixScheme for TimestampSuffixScheme {
+impl SuffixScheme for AppendTimestamp {
     type Repr = TimestampSuffix;
 
     fn rotate_file(
@@ -245,13 +266,12 @@ impl SuffixScheme for TimestampSuffixScheme {
     }
 }
 
-/// How to determine if a file should be deleted, in the case of [TimestampSuffixScheme].
+/// How to determine whether a file should be deleted, in the case of [AppendTimestamp].
 #[cfg(feature = "chrono04")]
 pub enum FileLimit {
     /// Delete the oldest files if number of files is too high
     MaxFiles(usize),
-    /// Delete files whose by their age, determined by the suffix (only works in the case that
-    /// [TimestampSuffixScheme] is used)
+    /// Delete files whose age exceeds the `Duration` - age is determined by the suffix of the file
     Age(Duration),
 }
 
@@ -283,15 +303,38 @@ mod test {
 
     #[test]
     fn scan_suffixes() {
-        let directory = tempdir::TempDir::new("file-rotate").unwrap();
-        let directory = directory.path();
-        let log_path = directory.join("logs");
-        std::fs::create_dir_all(&log_path).unwrap();
-        File::create(log_path.join("all.log.20210911T121830")).unwrap();
-        File::create(log_path.join("all.log.20210911T121831.gz")).unwrap();
+        let working_dir = tempdir::TempDir::new("file-rotate").unwrap();
+        let working_dir = working_dir.path().join("dir");
+        let suffix_scheme = AppendTimestamp::default(FileLimit::Age(Duration::weeks(1)));
 
-        let suffix_scheme = TimestampSuffixScheme::default(FileLimit::Age(Duration::weeks(1)));
-        let paths = suffix_scheme.scan_suffixes(&log_path.join("all.log"));
-        assert_eq!(paths.len(), 2);
+        // Test `scan_suffixes` for different possible paths given to it
+        // (it used to have a bug taking e.g. "log".parent() --> panic)
+        for relative_path in ["logs/log", "./log", "log", "../log", "../logs/log"] {
+            std::fs::create_dir_all(&working_dir).unwrap();
+            println!("Testing relative path: {}", relative_path);
+            let relative_path = Path::new(relative_path);
+
+            let log_file = working_dir.join(relative_path);
+            let log_dir = log_file.parent().unwrap();
+            // Ensure all directories needed exist
+            std::fs::create_dir_all(log_dir).unwrap();
+
+            // We cd into working_dir
+            std::env::set_current_dir(&working_dir).unwrap();
+
+            // Need to create the log file in order to canonicalize it and then get the parent
+            File::create(working_dir.join(&relative_path)).unwrap();
+            let canonicalized = relative_path.canonicalize().unwrap();
+            let relative_dir = canonicalized.parent().unwrap();
+
+            File::create(relative_dir.join("log.20210911T121830")).unwrap();
+            File::create(relative_dir.join("log.20210911T121831.gz")).unwrap();
+
+            let paths = suffix_scheme.scan_suffixes(relative_path);
+            assert_eq!(paths.len(), 2);
+
+            // Cleanup
+            std::fs::remove_dir_all(&working_dir).unwrap();
+        }
     }
 }
